@@ -20,6 +20,8 @@
 from django.conf.urls import patterns,url,include
 
 urlpatterns = patterns('feedly.views',    
+    url("^pay/(?P<order_id>\d+)/$", "paypal_redirect", name="paypal_redirect"),
+    url("^execute", "paypal_execute" , name="paypal_execute"),
     (r'^mosaic','mosaic'),
     (r'^basketclean','basketclean'),
     (r'^basket','basket'),
